@@ -16,8 +16,6 @@ use lib catdir( $FindBin::Bin, 'lib' );
 use lib catdir( $FindBin::Bin, updir(), 'lib' );
 use lib catdir( $FindBin::Bin, updir(), 'lib', 'inc' );
 
-use fallback catdir($FindBin::Bin, updir(), 'lib', 'inc'), catdir($FindBin::Bin, updir(), 'lib', 'inc');
-
 use System::Info;
 use Test::Smoke::Util qw(do_pod2usage whereis);
 use Test::Smoke::Util::FindHelpers ':all';
@@ -114,9 +112,9 @@ or regenerate from previous _config:
 Current options:
 
   -d dfvalsprefix   Set prefix for a _dfconfig file (<prefix>)
-  -c configprefix   When ommited 'perlcurrent' is used
-  -j jclprefix      When ommited 'perlcurrent' is used
-  -l logprefix      When ommited 'perlcurrent' is used
+  -c configprefix   When omitted 'perlcurrent' is used
+  -j jclprefix      When omitted 'perlcurrent' is used
+  -l logprefix      When omitted 'perlcurrent' is used
   -p prefix         Set -c and -j and -l at once
 
   -des              confirm all answers (needs previous _config)
@@ -415,7 +413,7 @@ my %opt = (
     gitorigin => {
         msg => "Git main repository?",
         alt => [ ],
-        dft => 'git://perl5.git.perl.org/perl.git',
+        dft => 'git://perl5.git.perl.org/perl5.git',
     },
     gitdir => {
         msg => "Directory for the local git repository?",
@@ -1326,7 +1324,7 @@ C<< $ENV{PERLIO} = "perlio"; >>). This feature should only be used with
 UTF8 locales, that is why this is checked (by regex only).
 
 B<If you know of a way to get the utf8 locales on your system, which is
-not coverd here, please let me know!>
+not covered here, please let me know!>
 
 =cut
 
@@ -1949,7 +1947,6 @@ sub write_sh {
     my $cwd = cwd();
     my $jcl = "$options{jcl}.sh";
     my $smokeperl = File::Spec->catfile( $FindBin::Bin, 'tssmokeperl.pl' );
-    my $archivelog = File::Spec->catfile( $FindBin::Bin, 'tsarchivelog.pl' );
     my $cronline = schedule_entry( File::Spec->catfile( $cwd, $jcl ),
                                    $cron, $crontime );
 
@@ -2000,7 +1997,6 @@ PATH=$FindBin::Bin:$ENV{PATH}
 export PATH
 umask $config{umask}
 $^X $smokeperl -c "\$CFGNAME" \$continue \$\* > $options{log} 2>&1
-$^X $archivelog -c "\$CFGNAME" \$continue \$\*
 
 rm "\$LOCKFILE"
 EO_SH
